/**
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

package P2PWNC;

/**
 * This class represents a P2PWNC user certificate, which is issued by a team for
 * one of its members. Such a certificate is composed of the user's public key, the
 * public key of the team that the user belongs to and the team's signature (the certificate
 * issuer signs the two public keys using its secret key).
 *
 * @author Pantelis Frangoudis
 * @author Elias Efstathiou
 * @version 0.0.1
 */
class P2PWNCCert extends P2PWNCProto {
      /**
       * Issuer team's public key.
       */
       protected P2PWNCKey teamPublicKey;

       /**
        * User's public key.
        */
        protected P2PWNCKey userPublicKey;

       /**
        * Signature of the issuer team (the team signs the two public keys using its secret key)
        */
        protected P2PWNCSignature teamSignature;

        /**
         * Constructs a certificate with null fields.
         */
        P2PWNCCert() {
                this.teamPublicKey = null;
                this.userPublicKey = null;
                this.teamSignature = null;
        }

        /**
         * Constructs a certificate with the specified parameters as the team's public key,
         * user's public key and team's signature.
         * @param teamPublicKey P2PWNCKey
         * The public key of the issuer team.
         * @param userPublicKey P2PWNCKey
         * The public key of the user.
         * @param teamSignature P2PWNCSignature
         * The signature generated by the team using its secret key.
         */
        P2PWNCCert(P2PWNCKey teamPublicKey, P2PWNCKey userPublicKey, P2PWNCSignature teamSignature) {
                this.teamPublicKey = teamPublicKey;
                this.userPublicKey = userPublicKey;
                this.teamSignature = teamSignature;
        }

        /**
         * Returns the team's public key.
         * @return P2PWNCKey
         */
        public P2PWNCKey getTeamPublicKey() {
                return this.teamPublicKey;
        }

        /**
         * Returns the user's public key.
         * @return P2PWNCKey
         */
        public P2PWNCKey getUserPublicKey() {
                return this.userPublicKey;
        }

        /**
         * Retirns the team's signature.
         */
        public P2PWNCSignature getTeamSignature() {
                return this.teamSignature;
        }

        /**
         * Sets the team's public key to the specified parameter.
         * @param teamPublicKey P2PWNCKey
         * The value teamPublicKey will be set to.
         */
        public void setTeamPublicKey(P2PWNCKey teamPublicKey) {
                this.teamPublicKey = teamPublicKey;
        }

        /**
         * Sets the user's public key to the specified parameter.
         * @param userPublicKey P2PWNCKey
         * The value userPublicKey will be set to.
         */
        public void setUserPublicKey(P2PWNCKey userPublicKey) {
                this.userPublicKey = userPublicKey;
        }

        /**
         * Sets the team signature to the specified parameter.
         * @param teamSignature P2PWNCSignature
         * The value teamSignature will be set to.
         */
        public void setTeamSignature(P2PWNCSignature teamSignature) {
                this.teamSignature = teamSignature;
        }

}
